@@ -46,6 +46,7 @@ class Command(BaseCommand):
         dstPath = options['output']
 
         logger = createLogger(__name__, options['log'])
+        machineLog = createLogger('ProductMachine', "MachineError.log")
         
         # create project
         machineName = hashlib.md5(
@@ -67,12 +68,13 @@ class Command(BaseCommand):
                 content = log.read()
             if content:
                 for f in os.listdir(machinePath):
-                    if f == 'BuildTemplates.log':
+                    if f == 'BuildTemplates.log' or f == 'AllError.log':
                         continue
                     if f.endswith('.log'):
                         with open(os.path.join(machinePath, f)) as log:
                             content += log.read()
-
+                with open(os.path.join(machinePath, 'AllError.log')) as err:
+                    machineLog.error(content + err.read())
                 content = content.strip().replace('\n', '|')
                 logger.error(content)
                 return 1
