@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10607 2017-12-05 09:15:47Z Lavender $
+# $Id: create_zip.py 10626 2017-12-10 09:05:41Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-05 17:15:47 +0800 (週二, 05 十二月 2017) $
-# $Revision: 10607 $
+# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
+# $Revision: 10626 $
 
 import os
 import shutil
@@ -21,6 +21,7 @@ import zipfile
 import json
 import hashlib
 import datetime
+import traceback
 
 from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
@@ -187,4 +188,6 @@ class Command(BaseCommand):
             logger.info('-----All OK!-----')
         except Exception as e:
             logger.error("create_zip error:%s" % e)
+            with open('./AllError.log', 'w+') as log:
+                log.write(traceback.format_exc())
             raise
\ No newline at end of file
